"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HashingFlags = void 0;
const command_1 = require("@oclif/command");
const EncodeTools_1 = require("@etomon/encode-tools/lib/EncodeTools");
const EncodeToolsBase_1 = require("./EncodeToolsBase");
const encodeBuffer_1 = require("./encodeBuffer");
exports.HashingFlags = {
    algorithm: command_1.flags.enum({
        char: 'a',
        required: false,
        default: EncodeToolsBase_1.getDefaults().hashAlgorithm,
        get options() {
            return [
                EncodeTools_1.HashAlgorithm.xxhash64,
                EncodeTools_1.HashAlgorithm.crc32,
                EncodeTools_1.HashAlgorithm.md5,
                EncodeTools_1.HashAlgorithm.bcrypt,
                ...(true /*EncodeToolsBase.isNative*/ ? [EncodeTools_1.HashAlgorithm.xxhash3] : []),
                EncodeTools_1.HashAlgorithm.sha1,
                EncodeTools_1.HashAlgorithm.xxhash32,
                EncodeTools_1.HashAlgorithm.sha512,
                EncodeTools_1.HashAlgorithm.sha3,
                EncodeTools_1.HashAlgorithm.sha2
            ];
        },
        description: 'Algorithm to use'
    }),
};
class Hash extends EncodeToolsBase_1.default {
    encoder(flags) {
        return new (EncodeToolsBase_1.default.EncodeTools)({
            binaryEncoding: flags.format,
            hashAlgorithm: flags.algorithm
        });
    }
    async run() {
        const { args, flags } = this.parse(Hash);
        const { input, output } = await this.getInputOutput(args);
        const enc = this.encoder(flags);
        const outputBuffer = enc.encodeBuffer(await enc.hash(input, flags.algorithm, ...flags.args || []), flags.format);
        output.end(outputBuffer);
        process.exit(0);
    }
}
exports.default = Hash;
Hash.description = 'Hashes data using the provided algorithm, writing the output to a file or stdout';
Hash.example = `echo 'hash me!' | encli hash -a md5 -f hex`;
Hash.aliases = ['hashString'];
Hash.flags = Object.assign(Object.assign(Object.assign({ help: command_1.flags.help() }, exports.HashingFlags), encodeBuffer_1.EncodingFlags), { args: command_1.flags.string({
        multiple: true,
        char: 'a',
        required: false,
        description: 'Additional args to pass to the encoder'
    }) });
Hash.args = [
    {
        name: 'inputBuffer',
        required: false,
        description: 'Path to input data, leave blank or use "-" for stdin',
        default: '-'
    },
    {
        name: 'returnValue',
        required: false,
        description: 'Path to use as output, leave blank or use "-" for stdout',
        default: '-'
    }
];
